summaryrefslogtreecommitdiff
path: root/src/bin/pg_dump/pg_backup.h
diff options
context:
space:
mode:
authorBruce Momjian <bruce@momjian.us>2004-08-20 04:20:23 +0000
committerBruce Momjian <bruce@momjian.us>2004-08-20 04:20:23 +0000
commitdaa076c4fdd32aff597eda4c34347d488c5b1e3a (patch)
tree82b9d6a320c0b8cb250fb9f4a19bf64f95233989 /src/bin/pg_dump/pg_backup.h
parent46be0c18f120466da9a9765d4ac15fdeaab4b0c7 (diff)
downloadpostgresql-daa076c4fdd32aff597eda4c34347d488c5b1e3a.tar.gz
> Please find attached a submission to add a "exit on error" option to
> pg_restore, as it seems that some people have scripts that rely on the > previous "abort on error" default behavior when restoring data with a > direct connection. > > Fabien Coelho
Diffstat (limited to 'src/bin/pg_dump/pg_backup.h')
-rw-r--r--src/bin/pg_dump/pg_backup.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/bin/pg_dump/pg_backup.h b/src/bin/pg_dump/pg_backup.h
index 4957ea9a14..7723203df7 100644
--- a/src/bin/pg_dump/pg_backup.h
+++ b/src/bin/pg_dump/pg_backup.h
@@ -15,7 +15,7 @@
*
*
* IDENTIFICATION
- * $PostgreSQL: pgsql/src/bin/pg_dump/pg_backup.h,v 1.31 2004/07/13 03:00:17 momjian Exp $
+ * $PostgreSQL: pgsql/src/bin/pg_dump/pg_backup.h,v 1.32 2004/08/20 04:20:22 momjian Exp $
*
*-------------------------------------------------------------------------
*/
@@ -59,7 +59,7 @@ typedef struct _Archive
int maxRemoteVersion;
/* error handling */
- bool die_on_errors; /* whether to die on sql errors... */
+ bool exit_on_error; /* whether to exit on SQL errors... */
int n_errors; /* number of errors (if no die) */
/* The rest is private */
@@ -103,6 +103,7 @@ typedef struct _restoreOptions
char *username;
int ignoreVersion;
int requirePassword;
+ int exit_on_error;
bool *idWanted;
bool limitToList;